<?php

namespace App\Http\Controllers\Server;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Http\Requests\AcceptRequest;
use Illuminate\Support\Facades\Auth;

class AcceptController extends Controller
{
    /**
     *  @OA\Post(
     *    tags={"Servers:User"},
     *    path="/user/{id}/accept",
     *    summary="Accept a user's connection",
     *    @OA\Parameter(
     *      name="id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\RequestBody(
     *      ref="#/components/requestBodies/Accept"
     *    ),
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="403",
     *      description="Forbidden",
     *      @OA\JsonContent(
     *        @OA\Property(
     *          property="message",
     *          type="string",
     *        ),
     *      )
     *    ),
     *    @OA\Response(
     *      response="404",
     *      ref="#/components/responses/404"
     *    ),
     *    @OA\Response(
     *      response="422",
     *      ref="#/components/responses/422"
     *    ),
     *    @OA\Response(
     *      response="200",
     *      description="OK",
     *      @OA\JsonContent(
     *        @OA\Property(
     *          property="user",
     *          ref="#/components/schemas/User"
     *        ),
     *      ),
     *    ),
     *    security={{"server-jwt":{}}},
     *  )
     */
    public function accept(AcceptRequest $request, $id) {
        $server = Auth::guard('server')->user();
        $user = User::findOrFail($id);
        
        if ($user->server_state != 'connecting' || $user->server_token != $request->input('token') || $user->server_id != $server->id) {
            return response()->json([
                'message' => 'Wrong token',
            ], 403);
        }

        $user->connect($server);
        return response()->json([
            "user" => $user
        ], 200);
    }
}
