<?php

namespace Tests\Feature;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;

use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;

class RefreshTest extends TestCase
{
    use RefreshDatabase;
    
    public function test_no_auth()
    {
        $response = $this->post('/api/auth/refresh');
        $response->assertStatus(401);
    }
    
    public function test_wrong_token()
    {
        $response = $this->withHeaders([
            "Authorization" => "Bearer randombearer"
        ])->post('/api/auth/refresh');
        $response->assertStatus(401);
    }
    
    public function test_good()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);
        $token = Auth::login($user);

        $response = $this->withHeaders([
            "Authorization" => "Bearer " . $token
        ])->post('/api/auth/refresh');
        $response->assertStatus(200);
        $response->assertJsonStructure([
            "token",
            "user" => [
                "id",
                "username",
                "email",
                "created_at",
                "updated_at"
            ]
        ]);
    }
}
