<?php

namespace Tests\Feature;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithFaker;
use Tests\TestCase;

use App\Models\User;
use Illuminate\Support\Facades\Hash;

class RegisterTest extends TestCase
{
    use RefreshDatabase;

    public function test_empty()
    {
        $response = $this->postJson('/api/auth/register', []);
        $response->assertStatus(422);
        $this->assertDatabaseCount('users', 0);
    }
    
    public function test_invalid_email()
    {
        $response = $this->postJson('/api/auth/register', [
            "username" => "test",
            "email" => "somerandomshit",
            "password" => "testtest",
        ]);
        $response->assertStatus(422);
        $this->assertDatabaseCount('users', 0);
    }
    
    public function test_login_already_used()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $response = $this->postJson('/api/auth/register', [
            "username" => "test",
            "email" => "jaaj@localhost",
            "password" => "testtest",
        ]);
        $response->assertStatus(422);
        $this->assertDatabaseCount('users', 1);
    }
    
    public function test_email_already_used()
    {
        $user = User::create([
            'username' => 'test',
            'email' => 'test@localhost',
            'password' => Hash::make('test'),
        ]);

        $response = $this->postJson('/api/auth/register', [
            "username" => "jaaj",
            "email" => "test@localhost",
            "password" => "testtest",
        ]);
        $response->assertStatus(422);
        $this->assertDatabaseCount('users', 1);
    }
    
    public function test_good()
    {
        $response = $this->postJson('/api/auth/register', [
            "username" => "test",
            "email" => "test@localhost",
            "password" => "testtest",
        ]);
        $response->assertStatus(204);
        
        $this->assertDatabaseHas('users', [
            'username' => 'test'
        ]);
    }
}
